/* mbed Microcontroller Library
 * Copyright (c) 2019 ARM Limited
 * SPDX-License-Identifier: Apache-2.0
 */ 

#include "mbed.h"
#include <math.h>

#define PI 3.14159265

AnalogIn InUD(PA_0); // Entrée Up/Down
AnalogIn InLR(PA_1); // Entrée Left/Right

PwmOut moteur1_1(PA_10); 
PwmOut moteur1_2(PA_15);
PwmOut moteur2_1(PB_14);
PwmOut moteur2_2(PB_13);
PwmOut moteur3_1(PB_8);
PwmOut moteur3_2(PC_9);


int main() {

    // Initialisation Moteurs
    moteur1_1.period_ms(10);
    moteur1_2.period_ms(10);
    moteur2_1.period_ms(10);
    moteur2_2.period_ms(10);
    moteur3_1.period_ms(10);
    moteur3_2.period_ms(10);
    moteur1_1.write(0);
    moteur1_2.write(0);
    moteur2_1.write(0);
    moteur2_2.write(0);
    moteur3_1.write(0);
    moteur3_2.write(0);


    double measUD, measLR ;
    double x,y;
    double angle ;
    double rc1,rc2,rc3; 
    
    while(1){ 
        // Partie Prise analogique des mesures
        measUD = InUD.read();
        measLR = InLR.read();
        x = measLR - 0.5; // Les tensions sont prises entre 0 et 1 et sont centrées en 0 pour le calcul d'angle
        y = measUD - 0.5; 


        // Divergence de cas pour déterminer l'angle béta défini entre -pi et pi
        if (-0.03<x and x<0.03 and -0.03<y and y<0.03){ // Cas pour le joystick au repos
            rc1=0;
            rc2=0;
            rc3=0;
            angle = 0;
        }
        else{
            if(-0.03<x and x<0.03){
                if(y == 0.5){
                    angle = 0 ; 
                }
                else if(y == -0.5){
                    angle = PI; 
                }
            }
            if(-0.03<y and y<0.03){
                if(x == 0.5){
                    angle = PI/2 ;
                }
                else if(x == -0.5){
                    angle = -PI/2;
                }
            }
            if(y>0.03){
                angle = atan(y/x);
            }
            if(y<-0.03){
                angle = PI - atan(y/x) ;
            }

        // Différents rapports cycliques
        
        rc1 = abs(cos(PI/2 - angle));
        rc2 = abs(cos(-PI/6 - angle));
        rc3 = abs(cos(-(5*PI/6) - angle));

        }

        printf("angle = %lf , x = %lf , y = %lf\r\n",angle,x,y);
        printf("rc1=%lf , rc2=%lf , rc3=%lf\r\n",rc1, rc2, rc3);

        // Divergence de cas pour la valeur de l'angle
        if(0<angle and angle<(PI/3)){

            moteur1_1.write(rc1);
            moteur1_2.write(0);

            moteur2_1.write(0);
            moteur2_2.write(rc2);

            moteur3_1.write(rc3);
            moteur3_2.write(0);

        }
        else if((PI/3)<angle and angle<(2*PI/3)){

            moteur1_1.write(rc1);
            moteur1_2.write(0);

            moteur2_1.write(0);
            moteur2_2.write(rc2);

            moteur3_1.write(0);
            moteur3_2.write(rc3);

        }
        else if((2*PI)/3<angle and angle<PI){

            moteur1_1.write(rc1);
            moteur1_2.write(0);

            moteur2_1.write(rc2);
            moteur2_2.write(0);

            moteur3_1.write(0);
            moteur3_2.write(rc3);

        }
        else if(0>angle and angle>-PI/3){

            moteur1_1.write(0);
            moteur1_2.write(rc1);

            moteur2_1.write(rc2);
            moteur2_2.write(0);

            moteur3_1.write(0);
            moteur3_2.write(rc3);

        }
        else if(-PI/3>angle and angle>(-2*PI/3)){

            moteur1_1.write(0);
            moteur1_2.write(rc1);

            moteur2_1.write(rc2);
            moteur2_2.write(0);

            moteur3_1.write(rc3);
            moteur3_2.write(0);

        }
        else if((-2*PI)/3>angle and angle>-PI){

            moteur1_1.write(0);
            moteur1_2.write(rc1);

            moteur2_1.write(0);
            moteur2_2.write(rc2);

            moteur3_1.write(rc3);
            moteur3_2.write(0);

        }
        else if(angle == 0){

            moteur1_1.write(0);
            moteur1_2.write(0);

            moteur2_1.write(0);
            moteur2_2.write(rc2);

            moteur3_1.write(rc3);
            moteur3_2.write(0);

        }
        else if(angle == PI/3){

            moteur1_1.write(rc1);
            moteur1_2.write(0);

            moteur2_1.write(0);
            moteur2_2.write(rc2);

            moteur3_1.write(0);
            moteur3_2.write(0);

        }
        else if(angle == 2*PI/3){

            moteur1_1.write(rc1);
            moteur1_2.write(0);

            moteur2_1.write(0);
            moteur2_2.write(0);

            moteur3_1.write(0);
            moteur3_2.write(rc3);

        }
        else if(angle == PI){

            moteur1_1.write(0);
            moteur1_2.write(0);

            moteur2_1.write(rc2);
            moteur2_2.write(0);

            moteur3_1.write(0);
            moteur3_2.write(rc3);

        }
        else if(angle == -(PI/3)){

            moteur1_1.write(0);
            moteur1_2.write(rc1);

            moteur2_1.write(0);
            moteur2_2.write(0);

            moteur3_1.write(rc3);
            moteur3_2.write(0);

        }
        else if(angle == -(2*PI/3)){

            moteur1_1.write(0);
            moteur1_2.write(rc1);

            moteur2_1.write(rc2);
            moteur2_2.write(0);

            moteur3_1.write(0);
            moteur3_2.write(0);

        }
    }
}
